/* 
   Copyright (C) 2004 Robin Hogan

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <string>
#include <fstream>
#include <cstdlib>
#include "rplot.h"

#include "../helvetica_medium_r_adobe.h"

int
RFont::save_to_header_file(char *filename)
{
  char font_size[8];
  sprintf(font_size, "%d", pixel);

  ofstream file;
  string data_root = family + "_" + weight + "_" + font_size;

  file.open(filename);
  if (!file) {
    throw("Unable to open header file for writing");
  }
  file << "#include \"rplot.h\"\n";

  /* Glyphs */
  int num_chars = MAX_CHARS-1;
  while (num_chars && !exists[num_chars]) {
    num_chars--;
  }
  int length_glyph_data = goffset[num_chars] + glength[num_chars];

  file << "unsigned char " << data_root << "_glyphs[] = {"
       << std::showbase << std::hex;
  for (int i = 0; i < length_glyph_data-1; i++) {
    file << (int) glyphs[i] << ", ";
  }

  file << (int) glyphs[length_glyph_data-1]
       << std::dec << std::noshowbase << "};\n";

  file << "RFont " << data_root << " = { NULL, " << pixel << ",\n";
#define write_int(varname, member) file << "/* " << varname << " */\n {"; \
  for (int i = 0; i < MAX_CHARS-1; i++) { file << member[i] << ", "; } \
  file << member[MAX_CHARS-1] << "},\n"

  write_int("left", left);
  write_int("right", right);
  write_int("ascent", ascent);
  write_int("descent", descent);
  write_int("width", width);
  file << max_ascent << ", " << max_descent << ",\n";
  write_int("goffset", goffset);
  write_int("glength", glength);
  file << "\"" << family << "\", \"" << weight << "\", \""
       << slant << "\", \"" << foundry << "\",\n";
  file << "\"" << xname << "\", \"" << psname << "\", "
       << first << ", " << last << ", " << def << ",\n";
  write_int("exists", exists);
  file << "&" << data_root << "_glyphs};";
  file.close();
  return 0;
}
