#!/bin/bash
#
# This program processes cloud radar data to produce quicklooks
# and netCDF data files
#

echo "NEED TO ADD REFERENCES AND INSTITUTION GLOBAL ATTRIBUTES"

USE_DATE=""
SHOW_DIR=""

FREQ=94
SUFFIX=${FREQ}d.dat

if [ "$#" -gt 0 ]
then
    if [ "$1" = dir ]
    then
	SHOW_DIR="1"
    else
	USE_DATE=$1
        shift
    fi
fi

#PATH=/home/swrhgnrj/src/chil-0.7alpha0/plot:/home/swrhgnrj/src/chil-0.7alpha0/src:$PATH

DIR1="/cdrom0"
DIR2="/cdrom1"

NICE=nice

## OPTIONS ##

OPTIONS="-oscillator -noisegates 25 -noisefactor 3.0 -doubleclean -Zcal +23 -rangeoffset -420 -minelev 85 -reject 10 30 -maxfields 3 -averays 30 -sumdir /export/anvil/anvil-01/swrhgnrj/sum"
NC_OPTIONS=""
PLOT_OPTIONS="-xfs unix/:-1 -id 94 -range -50 10"

## GET FILES IN RIGHT ORDER ##

FILE1=$(\ls $DIR1/*$SUFFIX | head -1)
FILE2=$(\ls $DIR2/*$SUFFIX | head -1)

if [ "$FILE1" = "" ]
then
    if [ "$FILE2" = "" ]
    then
	echo "No radar data files found"
	exit
    else
	FILES=$(echo $DIR2/*$SUFFIX)
    fi
else
    if [ "$FILE2" = "" ]
    then
	FILES=$(echo $DIR1/*$SUFFIX)
    else
	DATE1=$(chilinfo $FILE1 -date)
	DATE2=$(chilinfo $FILE2 -date)
	if [ "$DATE1" -lt "$DATE2" ]
	then
            echo "$DATE1 < $DATE2"
	    FILES=$(echo $DIR1/*$SUFFIX $DIR2/*$SUFFIX)
	else
            echo "$DATE1 > $DATE2"
	    FILES=$(echo $DIR2/*$SUFFIX $DIR1/*$SUFFIX)
	fi
    fi
fi

echo "FILES: $FILES"

## MAIN LOOP ##

#FIRST is normally 2
FIRST=2

for FILE in $FILES
do
    if [ "$FIRST" -gt "1" ]
    then
	FIRST=$(expr "$FIRST" - 1)
	continue
    fi

    if [ "$USE_DATE" ]
    then
        DATE=$USE_DATE
    else
        DATE=$(chilinfo $FILE -date)
    fi

    if [ "$SHOW_DIR" ]
    then
	echo "$DATE ($FILE)"
	continue
    fi

    echo "*** CONVERTING $DATE TO NETCDF ***"
    COMMAND="$NICE chil2nc -date $DATE $FILES $OPTIONS $NC_OPTIONS $@"
    echo ">" $COMMAND
    $COMMAND

    echo "*** PLOTTING $DATE ***"
    COMMAND="$NICE cloudncplot $PLOT_OPTIONS"
    echo ">" $COMMAND -system "Chilbolton 94 GHz Cloud Radar (Galileo)" \
	${DATE}_94.nc
    $COMMAND -system "Chilbolton 94 GHz Cloud Radar (Galileo)" \
	${DATE}_94.nc

    if [ "$USE_DATE" ]
    then
        break
    fi

done



